@@ -1,5 +1,6 @@
 import argparse
 import sys
+import sysconfig
 
 from pdm import termui
 from pdm.cli import actions
@@ -51,11 +52,14 @@ class Command(BaseCommand):
         if not plugins:
             return
         plugin_root = project.root / ".pdm-plugins"
-        environment = PythonEnvironment(project, python=sys.executable, prefix=str(plugin_root))
+        extra_paths = list({sysconfig.get_path("purelib"), sysconfig.get_path("platlib")})
+        environment = PythonEnvironment(
+            project, python=sys.executable, prefix=str(plugin_root), extra_paths=extra_paths
+        )
         with project.core.ui.open_spinner("[success]Installing plugins...[/]"):
             with project.core.ui.logging("install-plugins"):
                 install_requirements(
-                    plugins, environment, clean=True, use_install_cache=project.config["install.cache"]
+                    plugins, environment, clean=True, use_install_cache=project.config["install.cache"], allow_uv=False
                 )
             if not plugin_root.joinpath(".gitignore").exists():
                 plugin_root.mkdir(exist_ok=True)
