@@ -8,7 +8,7 @@ import warnings
 from functools import cached_property
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import TYPE_CHECKING, Any, cast, no_type_check
+from typing import TYPE_CHECKING, Any, ClassVar, cast, no_type_check
 from zipfile import ZipFile
 
 from packaging.version import InvalidVersion
@@ -124,6 +124,7 @@ class Candidate:
         "_requires_python",
         "_revision",
         "hashes",
+        "installed",
         "link",
         "name",
         "req",
@@ -138,6 +139,7 @@ class Candidate:
         name: str | None = None,
         version: str | None = None,
         link: Link | None = None,
+        installed: im.Distribution | None = None,
     ):
         """
         :param req: the requirement that produces this candidate.
@@ -154,6 +156,7 @@ class Candidate:
         self.summary = ""
         self.hashes: list[FileHash] = []
         self.requested = False
+        self.installed: im.Distribution | None = installed
 
         self._requires_python: str | None = None
         self._prepared: PreparedCandidate | None = None
@@ -163,7 +166,7 @@ class Candidate:
         return self.req.identify()
 
     def copy_with(self, requirement: Requirement) -> Candidate:
-        can = Candidate(requirement, name=self.name, version=self.version, link=self.link)
+        can = Candidate(requirement, name=self.name, version=self.version, link=self.link, installed=self.installed)
         can.summary = self.summary
         can.hashes = self.hashes
         can._requires_python = self._requires_python
@@ -306,6 +309,8 @@ class PreparedCandidate:
     The metadata and built wheel are available.
     """
 
+    _build_dir_cache: ClassVar[dict[Link, str]] = {}
+
     candidate: Candidate
     environment: BaseEnvironment
     reporter: CandidateReporter = dataclasses.field(default_factory=CandidateReporter)
@@ -481,6 +486,9 @@ class PreparedCandidate:
             self._unpacked_dir = result
 
     def prepare_metadata(self, force_build: bool = False) -> im.Distribution:
+        if self.candidate.installed is not None:
+            return self.candidate.installed
+
         self._obtain(allow_all=True, unpack=False)
         if self._metadata_dir:
             return im.PathDistribution(Path(self._metadata_dir))
@@ -654,11 +662,10 @@ class PreparedCandidate:
         return cache_entry
 
     def _get_build_dir(self) -> str:
-        original_link = self.candidate.link
-        assert original_link
-        if original_link.is_file and original_link.file_path.is_dir():
+        assert self.link is not None
+        if self.link.is_file and self.link.file_path.is_dir():
             # Local directories are built in tree
-            return str(original_link.file_path)
+            return str(self.link.file_path)
         if self.req.editable:
             # In this branch the requirement must be an editable VCS requirement.
             # The repository will be unpacked into a *persistent* src directory.
@@ -676,10 +683,14 @@ class PreparedCandidate:
             src_dir.mkdir(exist_ok=True, parents=True)
             dirname = self.candidate.name or self.req.name
             if not dirname:
-                dirname, _ = os.path.splitext(original_link.filename)
+                dirname, _ = os.path.splitext(self.link.filename)
             return str(src_dir / str(dirname))
         # Otherwise, for source dists, they will be unpacked into a *temp* directory.
-        return self.environment.project.core.create_temp_dir(prefix="pdm-build-")
+        if (build_dir := self._build_dir_cache.get(self.link)) is None:
+            build_dir = self._build_dir_cache[self.link] = self.environment.project.core.create_temp_dir(
+                prefix="pdm-build-"
+            )
+        return build_dir
 
     def _wheel_compatible(self, wheel_file: str, allow_all: bool = False) -> bool:
         env_spec = self.environment.allow_all_spec if allow_all else self.environment.spec
