@@ -202,6 +202,8 @@ class Requirement:
         """Return whether the passed in PEP 508 string
         is the same requirement as this one.
         """
+        if not isinstance(line, str):
+            return False
         req = parse_line(line)
         return self.key == req.key or (
             isinstance(self, FileRequirement) and isinstance(req, FileRequirement) and self.url == req.url
@@ -237,6 +239,10 @@ class NamedRequirement(Requirement):
         return f"{self.project_name}{extras}{self.specifier or ''}{self._format_marker()}"
 
 
+# Cache for checked paths to avoid checking the same path multiple times
+_checked_paths: set[Path] = set()
+
+
 @dataclasses.dataclass(eq=False)
 class FileRequirement(Requirement):
     url: str = ""
@@ -298,7 +304,7 @@ class FileRequirement(Requirement):
         else:
             result = self.path.as_posix()
         result = posixpath.normpath(result)
-        if not result.startswith(("./", "../")):
+        if not result.startswith(("./", "../")) and result != ".":
             result = "./" + result
         if result.startswith("./../"):
             result = result[2:]
@@ -310,11 +316,6 @@ class FileRequirement(Requirement):
             if not self.url and path.is_absolute():
                 self.url = path.as_uri() + fragments
                 self.path = path
-            # For relative path, we don't resolve URL now, so the path may still contain fragments,
-            # it will be handled in `relocate()` method.
-            result = Setup.from_directory(self.absolute_path)  # type: ignore[arg-type]
-            if result.name:
-                self.name = result.name
         else:
             url = url_without_fragments(self.url)
             relpath = get_relative_path(url)
@@ -326,6 +327,18 @@ class FileRequirement(Requirement):
             else:
                 self.path = Path(relpath)
 
+        if self.path is not None and self.absolute_path not in _checked_paths:
+            # For relative path, we don't resolve URL now, so the path may still contain fragments,
+            # it will be handled in `relocate()` method.
+            assert self.absolute_path is not None
+            # There is a risk of infinite recursion here if the project file contains file dependencies
+            # referring to itself, mark the path as being checked to avoid that.
+            _checked_paths.add(self.absolute_path)
+            result = Setup.from_directory(self.absolute_path)
+            if result.name:
+                self.name = result.name
+            _checked_paths.discard(self.absolute_path)
+
         if self.url:
             self._parse_name_from_url()
 
